@@ -13,4 +13,7 @@ typedef void (*xml6_gbl_MessageCallback) (const char *msg,
 
 DLLEXPORT  void xml6_gbl_message_func(void *ctx,char *fmt, ...);
 
+DLLEXPORT void* xml6_gbl_save_error_handlers(void);
+DLLEXPORT void xml6_gbl_restore_error_handlers(void*);
+
 #endif /* __XML6_GBL_H */
